Reference manual
================

Leaves
------

..  toctree::
    :numbered:

    chords
    notes
    rests

Containers
----------

..  toctree::
    :numbered:

    containers
    measures
    scores
    staves
    tuplets
    voices

Attachments
-----------

..  toctree::
    :numbered:

    annotations
    articulations
    instruments
    lilypond_commands
    lilypond_comments

LilyPond files
--------------

..  toctree::
    :numbered:

    lilypond_files

Pitches
-------

..  toctree::
    :numbered:

    named_pitches
